
import java.util.Map;
import java.util.Set;
import org.hornetq.api.core.SimpleString;
import org.hornetq.api.core.TransportConfiguration;
import org.hornetq.api.core.client.ClientConsumer;
import org.hornetq.api.core.client.ClientMessage;
import org.hornetq.api.core.client.ClientProducer;
import org.hornetq.api.core.client.ClientSession;
import org.hornetq.api.core.client.ClientSession.QueueQuery;
import org.hornetq.api.core.client.ClientSessionFactory;
import org.hornetq.api.core.client.HornetQClient;
import org.hornetq.core.config.Configuration;
import org.hornetq.core.config.impl.ConfigurationImpl;
import org.hornetq.core.remoting.impl.invm.InVMAcceptorFactory;
import org.hornetq.core.remoting.impl.invm.InVMConnectorFactory;
import org.hornetq.core.server.HornetQServer;
import org.hornetq.core.server.HornetQServers;
import org.hornetq.core.settings.impl.AddressSettings;

public class FilterTest {

  public static void main(String[] args) throws Exception {
    FilterTest test = new FilterTest();
    test.run();
  }

  void run() throws Exception {
    // Configure HornetQ server
    final Configuration configuration = new ConfigurationImpl();
    configuration.setPersistenceEnabled(false);
    configuration.setSecurityEnabled(false);
    final Set<TransportConfiguration> acceptors = configuration.getAcceptorConfigurations();
    acceptors.add(new TransportConfiguration(InVMAcceptorFactory.class.getName()));
    // Uncomment to try to send to DLA with no DLA configured - pretending the message to be discarded
    //final Map<String, AddressSettings> addresses = configuration.getAddressesSettings();
    //AddressSettings address = new AddressSettings();
    //address.setSendToDLAOnNoRoute(true);
    //addresses.put("test", address);
    // create and start it
    final HornetQServer hornetqServer = HornetQServers.newHornetQServer(configuration);
    hornetqServer.start();


    // Get a client factory and session
    ClientSessionFactory factory = HornetQClient.createClientSessionFactory(new TransportConfiguration(InVMConnectorFactory.class.getName()));
    ClientSession session = factory.createSession();
    // and create a queue with a filter
    session.createQueue("test", "test", "color='red'", false);
    session.start();

    try {
      // publish some messages
      ClientProducer producer = session.createProducer();

      ClientMessage message1 = session.createMessage(false);
      message1.putStringProperty("color", "red");
      producer.send("test", message1);

      ClientMessage message2 = session.createMessage(false);
      message1.putStringProperty("color", "blue");
      producer.send("test", message2);

      producer.close();

      // Now start consuming
      ClientConsumer consumer = session.createConsumer("test");
      ClientMessage receive1 = consumer.receive(2000);
      if (receive1 == null)
        System.out.println("No 1st message received");
      else {
        receive1.acknowledge();
        System.out.println("1st message: color=" + receive1.getStringProperty("color"));
      }
      ClientMessage receive2 = consumer.receive(2000);
      if (receive2 == null)
        System.out.println("No 2nd message received");
      else {
        receive2.acknowledge();
        System.out.println("2nd message: color=" + receive2.getStringProperty("color"));
      }

      QueueQuery queue = session.queueQuery(SimpleString.toSimpleString("test"));
      System.out.println("Messages in queue: " + queue.getMessageCount());
    } finally {
      session.close();
      hornetqServer.stop();
    }
  }
}
